import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { BulkCreateMaintenancesModel } from '../model/bulkCreateMaintenancesModel';
import { BulkMaintenancesCreatedModel } from '../model/bulkMaintenancesCreatedModel';
import { CountModel } from '../model/countModel';
import { CreateMaintenanceModel } from '../model/createMaintenanceModel';
import { MaintenanceCreatedModel } from '../model/maintenanceCreatedModel';
import { MaintenanceListModel } from '../model/maintenanceListModel';
import { MaintenanceModel } from '../model/maintenanceModel';
import { Operation } from '../model/operation';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace operationsMaintenancesBulkPost {
    interface Params {
        /**
        * The definition of the maintenances.
        */
        body: BulkCreateMaintenancesModel;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Unique key for safely retrying requests without accidentally performing the same operation twice.  We'll always send back the same response for requests made with the same key,  and keys can't be reused with different request parameters. Keys expire after 24 hours.
        */
        idempotencyKey?: string;
    }
}
export declare namespace operationsMaintenancesByIdDelete {
    interface Params {
        /**
        * The ID of the maintenance.
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace operationsMaintenancesByIdGet {
    interface Params {
        /**
        * The ID of the maintenance.
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * List of all embedded resources that should be expanded in the response. Possible values are: unit. All other values will be silently ignored.
        */
        expand?: Array<ExpandEnum>;
    }
    type ExpandEnum = 'unit';
    const ExpandEnumValues: readonly "unit"[];
}
export declare namespace operationsMaintenancesByIdHead {
    interface Params {
        /**
        * The ID of the maintenance.
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace operationsMaintenancesByIdPatch {
    interface Params {
        /**
        * The ID of the maintenance.
        */
        id: string;
        /**
        * Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
        */
        body: Array<Operation>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace operationsMaintenancesGet {
    interface Params {
        /**
        * Filter result by property id
        */
        propertyId?: string;
        /**
        * Filter result by unit id
        */
        unitId?: string;
        /**
        * Filter all maintenance windows that end after the specified date and time<br />A date and time (without fractional second part) in UTC or with UTC offset as defined in <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>
        */
        from?: Date;
        /**
        * Filter all maintenance windows that start before the specified date and time<br />A date and time (without fractional second part) in UTC or with UTC offset as defined in <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>
        */
        to?: Date;
        /**
        * Filter result by maintenance types
        */
        types?: Array<TypesEnum>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
        */
        pageNumber?: number;
        /**
        * Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
        */
        pageSize?: number;
        /**
        * List of all embedded resources that should be expanded in the response. Possible values are: unit. All other values will be silently ignored.
        */
        expand?: Array<ExpandEnum>;
    }
    type TypesEnum = 'OutOfService' | 'OutOfOrder' | 'OutOfInventory';
    const TypesEnumValues: readonly TypesEnum[];
    type ExpandEnum = 'unit';
    const ExpandEnumValues: readonly "unit"[];
}
export declare namespace operationsMaintenancesPost {
    interface Params {
        /**
        * The definition of the maintenance.
        */
        body: CreateMaintenanceModel;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Unique key for safely retrying requests without accidentally performing the same operation twice.  We'll always send back the same response for requests made with the same key,  and keys can't be reused with different request parameters. Keys expire after 24 hours.
        */
        idempotencyKey?: string;
    }
}
export declare namespace operationsMaintenancescountGet {
    interface Params {
        /**
        * Filter result by property id
        */
        propertyId?: string;
        /**
        * Filter result by unit id
        */
        unitId?: string;
        /**
        * Filter all maintenance windows that end after the specified date and time<br />A date and time (without fractional second part) in UTC or with UTC offset as defined in <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>
        */
        from?: Date;
        /**
        * Filter all maintenance windows that start before the specified date and time<br />A date and time (without fractional second part) in UTC or with UTC offset as defined in <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>
        */
        to?: Date;
        /**
        * Filter result by maintenance types
        */
        types?: Array<TypesEnum>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
    type TypesEnum = 'OutOfService' | 'OutOfOrder' | 'OutOfInventory';
    const TypesEnumValues: readonly TypesEnum[];
}
export declare class MaintenanceService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Create multiple maintenances
     * Use this call to create multiple maintenances.&lt;br&gt;You must have at least one of these scopes: &#39;maintenances.create, setup.manage&#39;.
     * @param $params.body The definition of the maintenances.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.idempotencyKey Unique key for safely retrying requests without accidentally performing the same operation twice.  We&#39;ll always send back the same response for requests made with the same key,  and keys can&#39;t be reused with different request parameters. Keys expire after 24 hours.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    operationsMaintenancesBulkPost($params: operationsMaintenancesBulkPost.Params, observe?: 'body', reportProgress?: boolean): Observable<BulkMaintenancesCreatedModel>;
    operationsMaintenancesBulkPost($params: operationsMaintenancesBulkPost.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<BulkMaintenancesCreatedModel>>;
    operationsMaintenancesBulkPost($params: operationsMaintenancesBulkPost.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<BulkMaintenancesCreatedModel>>;
    /**
     * Delete a maintenance
     * Use this call to delete a maintenance. It is not possible to delete maintenances that started yesterday or earlier.&lt;br&gt;You must have at least one of these scopes: &#39;maintenances.delete, maintenances.manage&#39;.
     * @param $params.id The ID of the maintenance.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    operationsMaintenancesByIdDelete($params: operationsMaintenancesByIdDelete.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    operationsMaintenancesByIdDelete($params: operationsMaintenancesByIdDelete.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    operationsMaintenancesByIdDelete($params: operationsMaintenancesByIdDelete.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Get a specific maintenance
     * Get a specific maintenance by ID.&lt;br&gt;You must have at least one of these scopes: &#39;maintenances.read, maintenances.manage&#39;.
     * @param $params.id The ID of the maintenance.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.expand List of all embedded resources that should be expanded in the response. Possible values are: unit. All other values will be silently ignored.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    operationsMaintenancesByIdGet($params: operationsMaintenancesByIdGet.Params, observe?: 'body', reportProgress?: boolean): Observable<MaintenanceModel>;
    operationsMaintenancesByIdGet($params: operationsMaintenancesByIdGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<MaintenanceModel>>;
    operationsMaintenancesByIdGet($params: operationsMaintenancesByIdGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<MaintenanceModel>>;
    /**
     * Check if a maintenance exists
     * Check if a maintenance exists by ID.&lt;br&gt;You must have at least one of these scopes: &#39;maintenances.read, maintenances.manage&#39;.
     * @param $params.id The ID of the maintenance.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    operationsMaintenancesByIdHead($params: operationsMaintenancesByIdHead.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    operationsMaintenancesByIdHead($params: operationsMaintenancesByIdHead.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    operationsMaintenancesByIdHead($params: operationsMaintenancesByIdHead.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Modify a maintenance
     * You can only change maintenances which are in the future or still ongoing today.  Here is the list of operations that are currently allowed:  - Add, replace and remove Description  - Replace From and To. &#39;From&#39; cannot be changed, if the maintenance started yesterday or before.&lt;br&gt;You must have this scope: &#39;maintenances.manage&#39;.
     * @param $params.id The ID of the maintenance.
     * @param $params.body Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    operationsMaintenancesByIdPatch($params: operationsMaintenancesByIdPatch.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    operationsMaintenancesByIdPatch($params: operationsMaintenancesByIdPatch.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    operationsMaintenancesByIdPatch($params: operationsMaintenancesByIdPatch.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Get list of maintenances
     * Get a list of maintenances matching your filter.&lt;br&gt;You must have at least one of these scopes: &#39;maintenances.read, maintenances.manage&#39;.
     * @param $params.propertyId Filter result by property id
     * @param $params.unitId Filter result by unit id
     * @param $params.from Filter all maintenance windows that end after the specified date and time&lt;br /&gt;A date and time (without fractional second part) in UTC or with UTC offset as defined in &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;
     * @param $params.to Filter all maintenance windows that start before the specified date and time&lt;br /&gt;A date and time (without fractional second part) in UTC or with UTC offset as defined in &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;
     * @param $params.types Filter result by maintenance types
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.pageNumber Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
     * @param $params.pageSize Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
     * @param $params.expand List of all embedded resources that should be expanded in the response. Possible values are: unit. All other values will be silently ignored.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    operationsMaintenancesGet($params: operationsMaintenancesGet.Params, observe?: 'body', reportProgress?: boolean): Observable<MaintenanceListModel | null>;
    operationsMaintenancesGet($params: operationsMaintenancesGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<MaintenanceListModel | null>>;
    operationsMaintenancesGet($params: operationsMaintenancesGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<MaintenanceListModel | null>>;
    /**
     * Create a new maintenance window
     * Use this call to create a new maintenance window for the given unit. You can only create maintenances for today and days in the future.&lt;br&gt;You must have at least one of these scopes: &#39;maintenances.create, maintenances.manage&#39;.
     * @param $params.body The definition of the maintenance.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.idempotencyKey Unique key for safely retrying requests without accidentally performing the same operation twice.  We&#39;ll always send back the same response for requests made with the same key,  and keys can&#39;t be reused with different request parameters. Keys expire after 24 hours.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    operationsMaintenancesPost($params: operationsMaintenancesPost.Params, observe?: 'body', reportProgress?: boolean): Observable<MaintenanceCreatedModel>;
    operationsMaintenancesPost($params: operationsMaintenancesPost.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<MaintenanceCreatedModel>>;
    operationsMaintenancesPost($params: operationsMaintenancesPost.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<MaintenanceCreatedModel>>;
    /**
     * Returns number of maintenances
     * Returns the number of maintenances matching your filter.&lt;br&gt;You must have at least one of these scopes: &#39;maintenances.read, maintenances.manage&#39;.
     * @param $params.propertyId Filter result by property id
     * @param $params.unitId Filter result by unit id
     * @param $params.from Filter all maintenance windows that end after the specified date and time&lt;br /&gt;A date and time (without fractional second part) in UTC or with UTC offset as defined in &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;
     * @param $params.to Filter all maintenance windows that start before the specified date and time&lt;br /&gt;A date and time (without fractional second part) in UTC or with UTC offset as defined in &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;
     * @param $params.types Filter result by maintenance types
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    operationsMaintenancescountGet($params: operationsMaintenancescountGet.Params, observe?: 'body', reportProgress?: boolean): Observable<CountModel>;
    operationsMaintenancescountGet($params: operationsMaintenancescountGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CountModel>>;
    operationsMaintenancescountGet($params: operationsMaintenancescountGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CountModel>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<MaintenanceService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<MaintenanceService>;
}
