import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ReplaceUnitConditionListModel } from '../model/replaceUnitConditionListModel';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace operationsAccountingConfigUpdatesPut {
    interface Params {
        /**
        * The property the update should be performed for
        */
        propertyId: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace operationsNightAuditPut {
    interface Params {
        /**
        * The property the night audit should be performed for
        */
        propertyId: string;
        /**
        * Flag if reservations in the state confirmed, which should have been checked in by now, should be marked as no show.                The default value is true and we strongly advise against setting it to false,  because different reports rely on setting reservations which were not checked in correctly to no show.
        */
        setReservationsToNoShow?: boolean;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace operationsUnitsConditionPut {
    interface Params {
        /**
        * Array of unit Ids with their respective new condition
        */
        body: ReplaceUnitConditionListModel;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare class OperationsService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Performs the updates for changed accounting config to unposted charges for a property.
     * The process will re-create all unposted charges for services,  fees and time slices where the accounting config applicable has changed from a certain future date.&lt;br&gt;You must have this scope: &#39;admin&#39;.
     * @param $params.propertyId The property the update should be performed for
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    operationsAccountingConfigUpdatesPut($params: operationsAccountingConfigUpdatesPut.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    operationsAccountingConfigUpdatesPut($params: operationsAccountingConfigUpdatesPut.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    operationsAccountingConfigUpdatesPut($params: operationsAccountingConfigUpdatesPut.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Performs the night audit for one property.
     * The night audit will post all charges for services that were delivered on the past business day in the folio and set all occupied rooms to &#39;Dirty&#39;&lt;br&gt;You must have at least one of these scopes: &#39;operations.manage, operations.trigger-night-audit&#39;.
     * @param $params.propertyId The property the night audit should be performed for
     * @param $params.setReservationsToNoShow Flag if reservations in the state confirmed, which should have been checked in by now, should be marked as no show.                The default value is true and we strongly advise against setting it to false,  because different reports rely on setting reservations which were not checked in correctly to no show.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    operationsNightAuditPut($params: operationsNightAuditPut.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    operationsNightAuditPut($params: operationsNightAuditPut.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    operationsNightAuditPut($params: operationsNightAuditPut.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Change the condition of a unit
     * &lt;br&gt;You must have this scope: &#39;operations.change-room-state&#39;.
     * @param $params.body Array of unit Ids with their respective new condition
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    operationsUnitsConditionPut($params: operationsUnitsConditionPut.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    operationsUnitsConditionPut($params: operationsUnitsConditionPut.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    operationsUnitsConditionPut($params: operationsUnitsConditionPut.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<OperationsService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<OperationsService>;
}
