import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Optional, Inject, NgModule, SkipSelf } from '@angular/core';
import * as i1 from '@angular/common/http';
import { HttpUrlEncodingCodec, HttpParams, HttpHeaders } from '@angular/common/http';
import { dateToApaleoIso } from '@apaleo/angular-api-proxy-common';

/**
* CustomHttpUrlEncodingCodec
* Fix plus sign (+) not encoding, so sent as blank space
* See: https://github.com/angular/angular/issues/11058#issuecomment-247367318
*/
class CustomHttpUrlEncodingCodec extends HttpUrlEncodingCodec {
    encodeKey(k) {
        k = super.encodeKey(k);
        return k.replace(/\+/gi, '%2B');
    }
    encodeValue(v) {
        v = super.encodeValue(v);
        return v.replace(/\+/gi, '%2B');
    }
}

const BASE_PATH = new InjectionToken('basePath');
const COLLECTION_FORMATS = {
    'csv': ',',
    'tsv': '   ',
    'ssv': ' ',
    'pipes': '|'
};

class Configuration {
    constructor(configurationParameters = {}) {
        this.apiKeys = configurationParameters.apiKeys;
        this.username = configurationParameters.username;
        this.password = configurationParameters.password;
        this.accessToken = configurationParameters.accessToken;
        this.basePath = configurationParameters.basePath;
        this.withCredentials = configurationParameters.withCredentials;
    }
    /**
     * Select the correct content-type to use for a request.
     * Uses {@link Configuration#isJsonMime} to determine the correct content-type.
     * If no content type is found return the first found type if the contentTypes is not empty
     * @param contentTypes - the array of content types that are available for selection
     * @returns the selected content-type or <code>undefined</code> if no selection could be made.
     */
    selectHeaderContentType(contentTypes) {
        if (contentTypes.length == 0) {
            return undefined;
        }
        let type = contentTypes.find(x => this.isJsonMime(x));
        if (type === undefined) {
            return contentTypes[0];
        }
        return type;
    }
    /**
     * Select the correct accept content-type to use for a request.
     * Uses {@link Configuration#isJsonMime} to determine the correct accept content-type.
     * If no content type is found return the first found type if the contentTypes is not empty
     * @param accepts - the array of content types that are available for selection.
     * @returns the selected content-type or <code>undefined</code> if no selection could be made.
     */
    selectHeaderAccept(accepts) {
        if (accepts.length == 0) {
            return undefined;
        }
        let type = accepts.find(x => this.isJsonMime(x));
        if (type === undefined) {
            return accepts[0];
        }
        return type;
    }
    /**
     * Check if the given MIME is a JSON MIME.
     * JSON MIME examples:
     *   application/json
     *   application/json; charset=UTF8
     *   APPLICATION/JSON
     *   application/vnd.company+json
     * @param mime - MIME (Multipurpose Internet Mail Extensions)
     * @return True if the given MIME is JSON, false otherwise.
     */
    isJsonMime(mime) {
        const jsonMime = new RegExp('^(application\/json|[^;/ \t]+\/[^;/ \t]+[+]json)[ \t]*(;.*)?$', 'i');
        return mime != null && (jsonMime.test(mime) || mime.toLowerCase() === 'application/json-patch+json');
    }
}

/**
 * apaleo Operations API - not safe for work
 * Continuously evolving version - use at your own risk! Operational tasks like posting revenues, setting housekeeping status and processing no shows, etc.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append$1(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
var operationsMaintenancesByIdGet;
(function (operationsMaintenancesByIdGet) {
    operationsMaintenancesByIdGet.ExpandEnumValues = Object.freeze(['unit']);
})(operationsMaintenancesByIdGet || (operationsMaintenancesByIdGet = {}));
var operationsMaintenancesGet;
(function (operationsMaintenancesGet) {
    operationsMaintenancesGet.TypesEnumValues = Object.freeze(['OutOfService', 'OutOfOrder', 'OutOfInventory']);
    operationsMaintenancesGet.ExpandEnumValues = Object.freeze(['unit']);
})(operationsMaintenancesGet || (operationsMaintenancesGet = {}));
var operationsMaintenancescountGet;
(function (operationsMaintenancescountGet) {
    operationsMaintenancescountGet.TypesEnumValues = Object.freeze(['OutOfService', 'OutOfOrder', 'OutOfInventory']);
})(operationsMaintenancescountGet || (operationsMaintenancescountGet = {}));
class MaintenanceService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    operationsMaintenancesBulkPost($params, observe = 'body', reportProgress = false) {
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling operationsMaintenancesBulkPost.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const idempotencyKey = $params.idempotencyKey;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        if (idempotencyKey !== undefined && idempotencyKey !== null) {
            headers = headers.set('Idempotency-Key', String(idempotencyKey));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/operations/v0-nsfw/maintenances/bulk`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    operationsMaintenancesByIdDelete($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling operationsMaintenancesByIdDelete.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.delete(`${this.basePath}/operations/v0-nsfw/maintenances/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    operationsMaintenancesByIdGet($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling operationsMaintenancesByIdGet.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const expand = $params.expand;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (expand) {
            queryParameters = queryParameters.set('expand', expand.join(COLLECTION_FORMATS['csv']));
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/operations/v0-nsfw/maintenances/${encodeURIComponent(String(id))}`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    operationsMaintenancesByIdHead($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling operationsMaintenancesByIdHead.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.head(`${this.basePath}/operations/v0-nsfw/maintenances/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    operationsMaintenancesByIdPatch($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling operationsMaintenancesByIdPatch.');
        }
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling operationsMaintenancesByIdPatch.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.patch(`${this.basePath}/operations/v0-nsfw/maintenances/${encodeURIComponent(String(id))}`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    operationsMaintenancesGet($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        const unitId = $params.unitId;
        const from = $params.from;
        const to = $params.to;
        const types = $params.types;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const pageNumber = $params.pageNumber;
        const pageSize = $params.pageSize;
        const expand = $params.expand;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (propertyId !== undefined && propertyId !== null) {
            queryParameters = queryParameters.set('propertyId', propertyId);
        }
        if (unitId !== undefined && unitId !== null) {
            queryParameters = queryParameters.set('unitId', unitId);
        }
        if (from !== undefined && from !== null) {
            queryParameters = queryParameters.set('from', dateToApaleoIso(from));
        }
        if (to !== undefined && to !== null) {
            queryParameters = queryParameters.set('to', dateToApaleoIso(to));
        }
        if (types) {
            queryParameters = queryParameters.set('types', types.join(COLLECTION_FORMATS['csv']));
        }
        if (pageNumber !== undefined && pageNumber !== null) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        if (pageSize !== undefined && pageSize !== null) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (expand) {
            queryParameters = queryParameters.set('expand', expand.join(COLLECTION_FORMATS['csv']));
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/operations/v0-nsfw/maintenances`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    operationsMaintenancesPost($params, observe = 'body', reportProgress = false) {
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling operationsMaintenancesPost.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const idempotencyKey = $params.idempotencyKey;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        if (idempotencyKey !== undefined && idempotencyKey !== null) {
            headers = headers.set('Idempotency-Key', String(idempotencyKey));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/operations/v0-nsfw/maintenances`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    operationsMaintenancescountGet($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        const unitId = $params.unitId;
        const from = $params.from;
        const to = $params.to;
        const types = $params.types;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (propertyId !== undefined && propertyId !== null) {
            queryParameters = queryParameters.set('propertyId', propertyId);
        }
        if (unitId !== undefined && unitId !== null) {
            queryParameters = queryParameters.set('unitId', unitId);
        }
        if (from !== undefined && from !== null) {
            queryParameters = queryParameters.set('from', dateToApaleoIso(from));
        }
        if (to !== undefined && to !== null) {
            queryParameters = queryParameters.set('to', dateToApaleoIso(to));
        }
        if (types) {
            queryParameters = queryParameters.set('types', types.join(COLLECTION_FORMATS['csv']));
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/operations/v0-nsfw/maintenances/$count`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function MaintenanceService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || MaintenanceService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: MaintenanceService, factory: MaintenanceService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(MaintenanceService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * apaleo Operations API - not safe for work
 * Continuously evolving version - use at your own risk! Operational tasks like posting revenues, setting housekeeping status and processing no shows, etc.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
class OperationsService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    operationsAccountingConfigUpdatesPut($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        if (propertyId === null || propertyId === undefined) {
            throw new Error('Required parameter propertyId was null or undefined when calling operationsAccountingConfigUpdatesPut.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (propertyId !== undefined && propertyId !== null) {
            queryParameters = queryParameters.set('propertyId', propertyId);
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.put(`${this.basePath}/operations/v0-nsfw/accounting-config-updates`, null, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    operationsNightAuditPut($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        if (propertyId === null || propertyId === undefined) {
            throw new Error('Required parameter propertyId was null or undefined when calling operationsNightAuditPut.');
        }
        const setReservationsToNoShow = $params.setReservationsToNoShow;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (propertyId !== undefined && propertyId !== null) {
            queryParameters = queryParameters.set('propertyId', propertyId);
        }
        if (setReservationsToNoShow !== undefined && setReservationsToNoShow !== null) {
            queryParameters = queryParameters.set('setReservationsToNoShow', setReservationsToNoShow);
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.put(`${this.basePath}/operations/v0-nsfw/night-audit`, null, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    operationsUnitsConditionPut($params, observe = 'body', reportProgress = false) {
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling operationsUnitsConditionPut.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(`${this.basePath}/operations/v0-nsfw/units-condition`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function OperationsService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || OperationsService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: OperationsService, factory: OperationsService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(OperationsService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

const APIS = [MaintenanceService, OperationsService];

var BulkCreateMaintenancesModel;
(function (BulkCreateMaintenancesModel) {
    BulkCreateMaintenancesModel.$metaData = {
        maintenances: Object.freeze({
            isRequired: true,
            type: 'Array<CreateMaintenanceModel>',
            isListContainer: true,
        }),
    };
})(BulkCreateMaintenancesModel || (BulkCreateMaintenancesModel = {}));

/**
 * apaleo Operations API - not safe for work
 * Continuously evolving version - use at your own risk! Operational tasks like posting revenues, setting housekeeping status and processing no shows, etc.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var BulkMaintenancesCreatedModel;
(function (BulkMaintenancesCreatedModel) {
    BulkMaintenancesCreatedModel.$metaData = {
        ids: Object.freeze({
            isRequired: true,
            type: 'Array<string>',
            isPrimitiveType: true,
            isListContainer: true,
        }),
    };
})(BulkMaintenancesCreatedModel || (BulkMaintenancesCreatedModel = {}));

/**
 * apaleo Operations API - not safe for work
 * Continuously evolving version - use at your own risk! Operational tasks like posting revenues, setting housekeeping status and processing no shows, etc.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CountModel;
(function (CountModel) {
    CountModel.$metaData = {
        count: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(CountModel || (CountModel = {}));

/**
 * apaleo Operations API - not safe for work
 * Continuously evolving version - use at your own risk! Operational tasks like posting revenues, setting housekeeping status and processing no shows, etc.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CreateMaintenanceModel;
(function (CreateMaintenanceModel) {
    CreateMaintenanceModel.TypeEnumValues = Object.freeze(['OutOfService', 'OutOfOrder', 'OutOfInventory']);
})(CreateMaintenanceModel || (CreateMaintenanceModel = {}));
(function (CreateMaintenanceModel) {
    CreateMaintenanceModel.$metaData = {
        unitId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        from: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        to: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        type: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CreateMaintenanceModel.TypeEnumValues,
            isPrimitiveType: true,
        }),
        description: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(CreateMaintenanceModel || (CreateMaintenanceModel = {}));

/**
 * apaleo Operations API - not safe for work
 * Continuously evolving version - use at your own risk! Operational tasks like posting revenues, setting housekeeping status and processing no shows, etc.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var EmbeddedUnitModel;
(function (EmbeddedUnitModel) {
    EmbeddedUnitModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        name: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        description: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        unitGroupId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(EmbeddedUnitModel || (EmbeddedUnitModel = {}));

/**
 * apaleo Operations API - not safe for work
 * Continuously evolving version - use at your own risk! Operational tasks like posting revenues, setting housekeeping status and processing no shows, etc.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var MaintenanceCreatedModel;
(function (MaintenanceCreatedModel) {
    MaintenanceCreatedModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(MaintenanceCreatedModel || (MaintenanceCreatedModel = {}));

/**
 * apaleo Operations API - not safe for work
 * Continuously evolving version - use at your own risk! Operational tasks like posting revenues, setting housekeeping status and processing no shows, etc.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var MaintenanceItemModel;
(function (MaintenanceItemModel) {
    MaintenanceItemModel.TypeEnumValues = Object.freeze(['OutOfService', 'OutOfOrder', 'OutOfInventory']);
})(MaintenanceItemModel || (MaintenanceItemModel = {}));
(function (MaintenanceItemModel) {
    MaintenanceItemModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        unit: Object.freeze({
            isRequired: true,
            type: 'EmbeddedUnitModel',
            metaData: EmbeddedUnitModel.$metaData
        }),
        from: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        to: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        type: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: MaintenanceItemModel.TypeEnumValues,
            isPrimitiveType: true,
        }),
        description: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(MaintenanceItemModel || (MaintenanceItemModel = {}));

var MaintenanceListModel;
(function (MaintenanceListModel) {
    MaintenanceListModel.$metaData = {
        maintenances: Object.freeze({
            isRequired: true,
            type: 'Array<MaintenanceItemModel>',
            isListContainer: true,
        }),
        count: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(MaintenanceListModel || (MaintenanceListModel = {}));

/**
 * apaleo Operations API - not safe for work
 * Continuously evolving version - use at your own risk! Operational tasks like posting revenues, setting housekeeping status and processing no shows, etc.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var MaintenanceModel;
(function (MaintenanceModel) {
    MaintenanceModel.TypeEnumValues = Object.freeze(['OutOfService', 'OutOfOrder', 'OutOfInventory']);
})(MaintenanceModel || (MaintenanceModel = {}));
(function (MaintenanceModel) {
    MaintenanceModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        unit: Object.freeze({
            isRequired: true,
            type: 'EmbeddedUnitModel',
            metaData: EmbeddedUnitModel.$metaData
        }),
        from: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        to: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        type: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: MaintenanceModel.TypeEnumValues,
            isPrimitiveType: true,
        }),
        description: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(MaintenanceModel || (MaintenanceModel = {}));

/**
 * apaleo Operations API - not safe for work
 * Continuously evolving version - use at your own risk! Operational tasks like posting revenues, setting housekeeping status and processing no shows, etc.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var MessageItemCollection;
(function (MessageItemCollection) {
    MessageItemCollection.$metaData = {
        messages: Object.freeze({
            type: 'Array<string>',
            isPrimitiveType: true,
            isListContainer: true,
        }),
    };
})(MessageItemCollection || (MessageItemCollection = {}));

/**
 * apaleo Operations API - not safe for work
 * Continuously evolving version - use at your own risk! Operational tasks like posting revenues, setting housekeeping status and processing no shows, etc.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var Operation;
(function (Operation) {
    Operation.$metaData = {
        value: Object.freeze({
            type: 'any',
            isPrimitiveType: true,
        }),
        path: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        op: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        from: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(Operation || (Operation = {}));

var ReplaceUnitConditionListModel;
(function (ReplaceUnitConditionListModel) {
    ReplaceUnitConditionListModel.$metaData = {
        unitsConditions: Object.freeze({
            isRequired: true,
            type: 'Array<ReplaceUnitConditionModel>',
            isListContainer: true,
        }),
    };
})(ReplaceUnitConditionListModel || (ReplaceUnitConditionListModel = {}));

/**
 * apaleo Operations API - not safe for work
 * Continuously evolving version - use at your own risk! Operational tasks like posting revenues, setting housekeeping status and processing no shows, etc.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ReplaceUnitConditionModel;
(function (ReplaceUnitConditionModel) {
    ReplaceUnitConditionModel.ConditionEnumValues = Object.freeze(['Clean', 'CleanToBeInspected', 'Dirty']);
})(ReplaceUnitConditionModel || (ReplaceUnitConditionModel = {}));
(function (ReplaceUnitConditionModel) {
    ReplaceUnitConditionModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        condition: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: ReplaceUnitConditionModel.ConditionEnumValues,
            isPrimitiveType: true,
        }),
    };
})(ReplaceUnitConditionModel || (ReplaceUnitConditionModel = {}));

class ApiModule {
    static forRoot(configurationFactory) {
        return {
            ngModule: ApiModule,
            providers: [{ provide: Configuration, useFactory: configurationFactory }]
        };
    }
    constructor(parentModule, http) {
        if (parentModule) {
            throw new Error('ApiModule is already loaded. Import in your base AppModule only.');
        }
        if (!http) {
            throw new Error('You need to import the HttpClientModule in your AppModule! \n' +
                'See also https://github.com/angular/angular/issues/20575');
        }
    }
    static { this.ɵfac = function ApiModule_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || ApiModule)(i0.ɵɵinject(ApiModule, 12), i0.ɵɵinject(i1.HttpClient, 8)); }; }
    static { this.ɵmod = /*@__PURE__*/ i0.ɵɵdefineNgModule({ type: ApiModule }); }
    static { this.ɵinj = /*@__PURE__*/ i0.ɵɵdefineInjector({ providers: [
            MaintenanceService,
            OperationsService
        ] }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(ApiModule, [{
        type: NgModule,
        args: [{
                imports: [],
                declarations: [],
                exports: [],
                providers: [
                    MaintenanceService,
                    OperationsService
                ]
            }]
    }], () => [{ type: ApiModule, decorators: [{
                type: Optional
            }, {
                type: SkipSelf
            }] }, { type: i1.HttpClient, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * Generated bundle index. Do not edit.
 */

export { APIS, ApiModule, BASE_PATH, BulkCreateMaintenancesModel, BulkMaintenancesCreatedModel, COLLECTION_FORMATS, Configuration, CountModel, CreateMaintenanceModel, EmbeddedUnitModel, MaintenanceCreatedModel, MaintenanceItemModel, MaintenanceListModel, MaintenanceModel, MaintenanceService, MessageItemCollection, Operation, OperationsService, ReplaceUnitConditionListModel, ReplaceUnitConditionModel, operationsMaintenancesByIdGet, operationsMaintenancesGet, operationsMaintenancescountGet };
//# sourceMappingURL=apaleo-angular-api-proxy-operations.mjs.map
